==> kdebase_3.3.2.orig.tar.gz: kdebase-3.3.2/kicker/taskmanager/tasklmbmenu.h <==
/*****************************************************************

Copyright (c) 2001 Matthias Elter <elter@kde.org>
Copyright (c) 2002 John Firebaugh <jfirebaugh@kde.org>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#ifndef __tasklmbmenu_h__
#define __tasklmbmenu_h__

#include <qpopupmenu.h>
#include <qtimer.h>

#include "taskmanager.h"

class TaskLMBMenu : public QPopupMenu
{
	Q_OBJECT
	
public:
	TaskLMBMenu( TaskList* list, QWidget *parent = 0, const char *name = 0 );
	
protected slots:
	void dragSwitch();
	
protected:
	void dragEnterEvent( QDragEnterEvent* );
	void dragLeaveEvent( QDragLeaveEvent* );
	void dragMoveEvent( QDragMoveEvent* );
	
private:
	void fillMenu( TaskList* tasks );
	
	TaskList&  m_tasks;
	int        m_lastDragId;
	QTimer     dragSwitchTimer;
};

#endif

==> kdebase_3.4.0.orig.tar.gz: kdebase-3.4.0/kicker/taskmanager/tasklmbmenu.h <==
/*****************************************************************

Copyright (c) 2001 Matthias Elter <elter@kde.org>
Copyright (c) 2002 John Firebaugh <jfirebaugh@kde.org>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#ifndef __tasklmbmenu_h__
#define __tasklmbmenu_h__

#include <qpopupmenu.h>
#include <qtimer.h>

#include "taskmanager.h"

class KDE_EXPORT TaskLMBMenu : public QPopupMenu
{
	Q_OBJECT
	
public:
	TaskLMBMenu( TaskList* list, QWidget *parent = 0, const char *name = 0 );
	
protected slots:
	void dragSwitch();
	
protected:
	void dragEnterEvent( QDragEnterEvent* );
	void dragLeaveEvent( QDragLeaveEvent* );
	void dragMoveEvent( QDragMoveEvent* );
	
private:
	void fillMenu( TaskList* tasks );
	
	TaskList&  m_tasks;
	int        m_lastDragId;
	QTimer     dragSwitchTimer;
};

#endif
